# medz/dutch/rss.py
#
#

""" rss module. """

__copyright__ = "Copyright 2015, B.H.J Thate"

## IMPORTS

from medz.utils.url import parse_urls
from medz.utils.time import short_date
from medz.utils.url import get_url, strip_html
from medz.errors import error
from medz.clock import Repeater
from medz.kernel import kernel
from medz.thing import Thing

import threading
import socket
import time

## DEFINES

key_list = ["published", "title", "link"]

seen = Thing()
seen.list = []
seen.results = "rss"
seen.prefix = "results"

## display function

def display(*args, **kwargs):
    entry = args[0]
    result = ""
    for key in key_list:
        if entry.get(key, None): result += "%s - " % entry[key]
    return result[:-3]

## get function

def get(url):
    import medz.extra.feedparser as fp
    result = []
    try:
        data = get_url("GET", url).read()
        data = fp.parse(data)
    except Exception as ex: error() ; return
    for entry in data["entries"]:
        o = Thing(entry)
        s = o.slice(key_list)
        if "summary" in o: o["summary"] = strip_html(o["summary"]).rstrip()
        o.prefix = "rss"
        o.short = short_date(time.ctime())
        yield o

## look function

def fetch(*args, **kwargs):
    global seen
    for fn in kernel.all():
        obj = Thing().load(fn)
        if "rss" not in obj: continue
        if "http" not in obj.rss: continue
        for o in get(obj.rss):
            if o.link in seen.list: continue
            seen.list.append(o.link)
            o.sync()
            kernel.announce(display(o))
            if "summary" in o: kernel.announce(o.summary)
    seen.sync()

kernel.register("rss.fetch", fetch)

## RSS

class RSS(Repeater): pass

## INIT

def init(*args, **kwargs):
    global seen
    last_rss = kernel.last("results", "rss")
    if last_rss: seen = last_rss
    rss = RSS(fetch, 600)
    kernel.put(rss.start)

def stop(*args, **kwargs):
    for thr in threading.enumerate():
        if "rss_fetch" in str(thr): thr.cancel()
